====================
depfinder Change Log
====================

.. current developments

v2.8.0
====================

**Added:**

* Added ``--custom-namespaces`` option for custom name space searching.

**Changed:**

* Changed handling of import maps to compute number of letters from upstream data.

**Authors:**

* Matthew R. Becker



v2.7.1
====================

**Authors:**

* Eric Dill



v2.7.0
====================

**Authors:**

* Christopher J. Wright



v2.6.2
====================

**Authors:**

* Christopher J. Wright



v2.6.1
====================

**Authors:**

* Christopher J. Wright



v2.6.0
====================

**Authors:**

* Christopher J. Wright



v2.5.1
====================

**Authors:**

* Christopher J. Wright



v2.5.0
====================

**Authors:**

* Christopher J. Wright
* Jonathan Karp



v2.4.1
====================

**Fixed:**

* Handle different encodings, for instance the BOM used in adal

**Authors:**

* Christopher J. Wright



v2.4.0
====================

**Added:**

* Support multiple ignore patterns at once

**Changed:**

* renamed blacklist to ignore

**Fixed:**

* Continue parsing despite errors

**Authors:**

* Eric Dill
* Christopher J. Wright


